# Processo e sviluppo del software - Assignment 1

## Gruppo ITIS 

- 851813 - Brugora Michael
- 852095 - Locatelli Riccardo
- 851810 - Magni Marco

## Progetto

- https://gitlab.com/magni5/2022_assignment1_itis

## Prima consegna

L'obiettivo è di realizzare una pipeline per il CI/CD di una semplice applicazione Python che si interfacci con un database.

La pipeline sarà costituita da 7 stage: Build, Verify, Unit Test, Integration Test, Package, Release, Deploy.

Allo stato attuale è stata realizzata l'applicazione e stiamo effettuando delle prove (anche detto "smanettando") per provare diverse configurazioni della pipeline. Seguiranno poi evoluzioni mirate a produrre un risultato rilevante e funzionante.
